@@ -32,9 +32,9 @@ def of_point(input_gdf, point_gdf, pop_clm=None,
 
     Parameters
     ----------
-    input_gdf : GeoDataFrame
+    input_gdf : geopandas.GeoDataFrame
         Input GeoDataFrame in which points are counted.
-    point_gdf : GeoDataFrame
+    point_gdf : geopandas.GeoDataFrame
         Point GeoDataFrame.
     pop_clm : str
         Population column which contains values to represent each occurrence
@@ -48,9 +48,46 @@ def of_point(input_gdf, point_gdf, pop_clm=None,
 
     Returns
     -------
-    output_sr : pd.Series
+    output_sr : pandas.Series
         A pandas Series that contains the density of point in each input
         geometry of the input GeoDataFrame.
+
+    Examples
+    --------
+    Calculate density of points (schools) in polygon layer (Alachua County 
+    census tracts) per square miles.
+
+    >>> pylusat.density.of_point(acs2016_gdf, schools_gdf, 
+                                 area_unit='square mile')
+    0   2.389447
+    1   0.000000
+    2   1.714565
+    3   4.974934
+    4   2.494981
+    ...
+    150 0.6607739
+    151 3.332871
+    152 0.967817
+    153 0.116269
+    154 1.140540
+
+    Calculate density of points (schools) in polygon layer (Alachua County 
+    census tracts) in square miles. Each occurrence of schools is represented 
+    by the enrollment column.
+
+    >>> pylusat.density.of_point(acs2016_gdf, schools_gdf, "ENROLLMENT", 
+                                 '1 mile', 'square mile')
+    0   0.000159
+    1   0.000252
+    2   0.000132
+    3   0.000117
+    4   0.000099
+    ...
+    150 0.000084
+    151 0.000114
+    152 0.000085
+    153 0.000031
+    154 0.000024
     """
     input_gdf_manager = GeoDataFrameManager(input_gdf)
     point_gdf_manager = GeoDataFrameManager(point_gdf)
@@ -94,9 +131,9 @@ def of_line(input_gdf, line_gdf, cellsize=30, search_radius=None,
 
     Parameters
     ----------
-    input_gdf : GeoDataFrame
+    input_gdf : geopandas.GeoDataFrame
         Input GeoDataFrame in which length of lines are summed.
-    line_gdf : GeoDataFrame
+    line_gdf : geopandas.GeoDataFrame
         Line GeoDataFrame whose lengths are summed.
     cellsize : float, optional
         The cell size used to rasterize the line_gdf.
@@ -106,16 +143,35 @@ def of_line(input_gdf, line_gdf, cellsize=30, search_radius=None,
     area_unit : str, optional
         A string of the area unit used for density calculation.
         e.g., "square meters".
-    geomtoarray : {tuple of (np.ndarray, Affine, np.ndarray, float), None}
+    geomtoarray : {tuple of (numpy.ndarray, Affine, numpy.ndarray, float), None}
         The output of ``rasterize_geometry`` function. If a desired output has
         already been created for the `line_gdf` has already been created,
         set it to be this argument to use it.
 
     Returns
     -------
-    output_sr : pd.Series
+    output_sr : pandas.Series
         A pandas Series that contains the density of line in each input
         geometry of the input GeoDataFrame.
+
+    Examples
+    --------
+    Calculate density of lines (highway) per square mile in Alachua County 
+    census tract polygons.
+
+    >>> pylusat.density.of_line(acs2016_gdf, highway_gdf, 
+                                search_radius='1 mile', area_unit='square mile')
+    0   0.000425
+    1   0.000705
+    2   0.000273
+    3   0.000753
+    4   0.000358
+    ...
+    150 0.000266
+    151 NaN
+    152 0.000277
+    153 NaN
+    154 0.000620    
     """
     from pylusat.utils import rasterize_geometry
     from rasterstats import zonal_stats
