@@ -14,14 +14,14 @@ def erase(input_gdf, erase_gdf=None):
 
     Parameters
     ----------
-    input_gdf : GeoDataFrame
+    input_gdf : geopandas.GeoDataFrame
         Input GeoDataFrame.
-    erase_gdf : GeoDataFrame
+    erase_gdf : geopandas.GeoDataFrame
         Erase GeoDataFrame containing the erase features.
 
     Returns
     -------
-    output : GeoDataFrame
+    output : geopandas.GeoDataFrame
         The remaining features after erasure.
     """
     if erase_gdf is None:
@@ -41,7 +41,7 @@ def spatial_join(target_gdf, join_gdf, op="intersects",
 
     Parameters
     ----------
-    target_gdf, join_gdf : GeoDataFrames
+    target_gdf, join_gdf : geopandas.GeoDataFrame
         The GeoDataFrame to join to the target GeoDataFrame.
     op : string, default 'intersects'
         Binary predicate, one of {'intersects', 'contains', 'within'}. See
@@ -61,9 +61,27 @@ def spatial_join(target_gdf, join_gdf, op="intersects",
         Whether to keep all features from the target GeoDataFrame.
     Returns
     -------
-    GeoDataFrame
+    geopandas.GeoDataFrame
         A GeoDataFrame contains all columns in the target GeoDataFrame and the
         specified columns from the join GeoDataFrame.
+    
+    Examples
+    -------
+    >>> pylusat.geotools.spatial_join(acs2016_gdf, schools_gdf, 
+                                      cols_agg={'ENROLLMENT': ['sum]})
+             GEOID10    ENROLLMENT_SUM
+    0   120010006001               0.0
+    1   120010006002               0.0
+    2   120010006003             345.0
+    3   120010007001              37.0
+    4   120010007002            1420.0
+    ...
+    150 120010022191             113.0
+    151 120010022192            1889.0
+    152 120010022193             118.0
+    153 120010022201               0.0
+    154 120011108001             803.0
+    
     """
     how = 'left' if keep_all else 'inner'
     gpd_sjoin = gpd.sjoin(target_gdf, join_gdf, how=how, op=op)
@@ -103,20 +121,20 @@ def within_dist(input_gdf, input_id, distance,
 
     Parameters
     ----------
-    input_gdf : GeoDataFrame
+    input_gdf : geopandas.GeoDataFrame
         The input set.
     input_id : str
         The name of the column containing the unique id of the input set.
     distance : int or float
         Distance (in the same unit as the input GeoDataFrame).
-    target_gdf : GeoDataFrame
+    target_gdf : geopandas.GeoDataFrame
         The target set.
     output_col : str
         The name of the output column.
 
     Returns
     -------
-    output : GeoDataFrame
+    output : geopandas.GeoDataFrame
         The output value is 1 if there exists any target object within the
         specified distance of the input object and 0 otherwise.
     """
@@ -140,9 +158,9 @@ def select_by_location(input_gdf, select_gdf,
 
     Parameters
     ----------
-    input_gdf : GeoDataFrame
+    input_gdf : geopandas.GeoDataFrame
         The input GeoDataFrame.
-    select_gdf : GeoDataFrame
+    select_gdf : geopandas.GeoDataFrame
         The selecting GeoDataFrame.
     op : string, default 'intersection'
         Binary predicate, one of {'intersects', 'contains', 'within',
@@ -153,8 +171,19 @@ def select_by_location(input_gdf, select_gdf,
         useful when op is set to be "within a distance".
     Returns
     -------
-    output : GeoDataFrame
+    output : geopandas.GeoDataFrame
         The selected features from the input GeoDataFrame.
+    
+    Examples
+    --------
+    >>> pylusat.geotools.select_by_location(acso2016_gdf, schools_gdf)
+               GEOID    geometry
+    0   120010006001    POLYGON ((564121.721 629847.127, 564127.038...))     
+    2   120010006003    POLYGON ((565858.254 629636.152, 565695.479...))
+    3   120010007001    POLYGON ((563316.398 627676.644, 563228.536...))
+    4   120010007002    POLYGON ((563768.801 627680.962, 563770.869...))
+    5   120010007003    POLYGON ((565229.514 624327.588, 564862.624...))
+    
     """
     ops = ['intersects', 'contains', 'within', 'within a distance']
     assert op in ops, 'invalid op parameter,'
@@ -173,24 +202,36 @@ def select_by_location(input_gdf, select_gdf,
     return output_gdf.copy()
 
 
-def combine(rast1_path, rast2_path):
+def combine(rast1, rast2):
     """
     Combines input rasters by their unique value pairs. Assigns new values to
     each unique pair.
+
     Parameters
     ----------
-    rast1_path : str
-        File path to the first raster.
-    rast2_path : str
-        File path to the second raster.
+    rast1 : str, rasterio.io.DatasetReader
+        File path to the first raster or a `DatasetReader` object of `rasterio`.
+    rast2 : str, rasterio.io.DatasetReader
+        File path to the second raster or a `DatasetReader` object of `rasterio`.
+
     Returns
     -------
-    Results : rasterio Dataset, DataFrame
+    Results : rasterio.Dataset, pandas.DataFrame
         The combined raster files as a Rasterio Dataset.
         The output attribute table as a Pandas DataFrame.
+
+    Examples
+    --------
+    >>> pylusat.geotools.combine(habitat_tif, habitati_tif)
+    0   1   0   0   618688
+    1   2   2   2   1
+    2   3   3   3   1
+    3   4   5   5   20539
+    4   5   6   6   115
+
     """
-    input_ras1 = RasterManager.from_path(rast1_path)
-    input_ras2 = RasterManager.from_path(rast2_path)
+    input_ras1 = RasterManager(rast1)
+    input_ras2 = RasterManager(rast2)
     arr1 = input_ras1.to_array()
     arr2 = input_ras2.to_array()
     arr1_1d = np.reshape(arr1, arr1.size)
@@ -242,7 +283,7 @@ def gridify(input_gdf, width=None, height=None, num_cols=None, num_rows=None):
 
     Parameters
     ----------
-    input_gdf : GeoDataFrame
+    input_gdf : geopandas.GeoDataFrame
         Input GeoDataFrame based on which the grid is created.
     width : int or float
         Cell width.
@@ -256,8 +297,26 @@ def gridify(input_gdf, width=None, height=None, num_cols=None, num_rows=None):
 
     Returns
     -------
-    GeoDataFrame
+    geopandas.GeoDataFrame
         The output grid (polygons).
+
+    Examples
+    --------
+    Create grid of polygons from the schools GeoDataFrame with a width of 1000
+
+    >>> pylusat.geotools.gridify(schools_gdf, width=1000)
+    0       POLYGON ((533359.960 611556.855, 534359.960...))
+    1       POLYGON ((534359.960 611556.855, 535359.960...))
+    2       POLYGON ((535359.960 611556.855, 536359.960...))
+    3       POLYGON ((536359.960 611556.855, 537359.960...))
+    4       POLYGON ((537359.960 611556.855, 538359.960...))
+    ...
+    2491    POLYGON ((580359.960 658556.855, 581359.960...))
+    2492    POLYGON ((581359.960 658556.855, 582359.960...))
+    2493    POLGYON ((582359.960 658556.855, 583359.960...))
+    2494    POLYGON ((583359.960 658556.855, 584359.960...))
+    2495    POLGYON ((584359.960 658556.855, 585359.960...))
+    
     """
     xmin, ymin, xmax, ymax = input_gdf.total_bounds
 
