@@ -17,9 +17,9 @@ def idw(input_gdf, value_gdf, value_clm, power=2, n_neighbor=12,
 
     Parameters
     ----------
-    input_gdf : GeoDataFrame
+    input_gdf : geopandas.GeoDataFrame
         Input GeoDataFrame. Centroids of the input geometries are used.
-    value_gdf : GeoDataFrame
+    value_gdf : geopandas.GeoDataFrame
         GeoDataFrame containing the values needed to be interpolated.
     value_clm : str
         The name of the column that holds the values in value_gdf.
@@ -37,15 +37,35 @@ def idw(input_gdf, value_gdf, value_clm, power=2, n_neighbor=12,
     min_dist : float, optional
         The distance below which the interpolated value will be set to equal to
         the value of its closest neighbor.
-    dtype : str or np.dtype, optional
+    dtype : str or numpy.dtype, optional
         Use a np.dtype or Python type to cast the interpolated values to the
         desired type.
 
     Returns
     -------
-    output_sr : Series
+    output_sr : pandas.Series
         pandas Series that contains the interpolated values for all feature in
         the input_gdf.
+
+    Examples
+    --------
+    Interpolate Enrollment values in Schools GeoDataFrame to the second power
+    with 12 neighborhoods.
+
+    >>> pylusat.interpolate.idw(acs2016_gdf, schools_gdf, 'ENROLLMENT',
+                                power=2.00, n_neighbor=12)
+    0    26.407251
+    1   137.199332
+    2   205.822340
+    3   231.137558
+    4   158.283367
+    ...
+    150 239.502760
+    151 404.536623
+    152 233.601194
+    153 228.459787
+    154 490.956496
+
     """
     if not (isinstance(n_neighbor, int) and
             1 <= n_neighbor <= len(value_gdf.index)):
